from typing import Any
import logging
import egpy.eg as eg
from eg_interp_events_pb2_grpc import EventsStub


def record(name: str, m: Any):
  '''
  Records a metric payload with the given name. the name
  field is an opaque string identifying the metric.
  the payload must be consistent for its mapping of field names to types.
  the prefix 'eg.' is reserved for system use.
  i.e.) ✓ record("example.metric.1",
  i.e.) x record("eg.example.metric.1",
  metrics will be encoded as follows:
    - every event will be given a uuid v7 id.
    - every event will be given a timestamp.
    - name will be recorded as its literal value and as a hashed uuid.
    - timestamps must be encoded as ISO8601.
  '''

  with eg.autoclient() as c:
    try:
      logging.info(f"recording metric {name} initiated")
      EventsStub(c).Dispatch(
        eg.dispatch(eg.metric(name, m)),
      )
    finally:
      logging.info(f"recording metric {name} completed")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eg.interp.events.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'eg.interp.events.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x65g.interp.events.proto\x12\x10\x65g.interp.events\"\x19\n\x0bRunMetadata\x12\n\n\x02id\x18\x01 \x01(\x0c\"R\n\tLogHeader\x12\r\n\x05Major\x18\x01 \x01(\x05\x12\r\n\x05Minor\x18\x02 \x01(\x05\x12\r\n\x05Patch\x18\x03 \x01(\x05\x12\x0b\n\x03sts\x18\x04 \x01(\x03\x12\x0b\n\x03\x65ts\x18\x05 \x01(\x03\"\x0b\n\tHeartbeat\"\xb3\x01\n\x04Task\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12+\n\x05state\x18\x04 \x01(\x0e\x32\x1c.eg.interp.events.Task.State\x12\x10\n\x08\x64\x65\x61\x64line\x18\x05 \x01(\x03\">\n\x05State\x12\x0b\n\x07Pending\x10\x00\x12\r\n\tInitiated\x10\x01\x12\r\n\tCompleted\x10\x02\x12\n\n\x05\x45rror\x10\xe8\x07\"2\n\x06Metric\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\nfieldsJSON\x18\xe8\x07 \x01(\x0cJ\x05\x08\x02\x10\xe8\x07\"\xe1\x01\n\x07Message\x12\n\n\x02id\x18\x01 \x01(\t\x12\n\n\x02ts\x18\x02 \x01(\x03\x12/\n\x08preamble\x18\x64 \x01(\x0b\x32\x1b.eg.interp.events.LogHeaderH\x00\x12\x30\n\theartbeat\x18\x65 \x01(\x0b\x32\x1b.eg.interp.events.HeartbeatH\x00\x12&\n\x04task\x18\x66 \x01(\x0b\x32\x16.eg.interp.events.TaskH\x00\x12*\n\x06metric\x18g \x01(\x0b\x32\x18.eg.interp.events.MetricH\x00\x42\x07\n\x05\x45vent\"\xc4\x01\n\x0eRunUploadChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x10\n\x08\x63hecksum\x18\x02 \x01(\x0c\x12\x0e\n\x04none\x18\x03 \x01(\x08H\x00\x12=\n\x08metadata\x18\x04 \x01(\x0b\x32).eg.interp.events.RunUploadChunk.MetadataH\x00\x1a+\n\x08Metadata\x12\r\n\x05\x62ytes\x18\x01 \x01(\x04\x12\x10\n\x08\x63hecksum\x18\x02 \x01(\x0c\x42\x16\n\x14initialChunkMetadata\"?\n\x11RunUploadResponse\x12*\n\x03run\x18\x01 \x01(\x0b\x32\x1d.eg.interp.events.RunMetadata\";\n\rRunLogRequest\x12*\n\x03run\x18\x01 \x01(\x0b\x32\x1d.eg.interp.events.RunMetadata\"!\n\x0eRunLogResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\x14\n\x12RunInitiateRequest\"\x13\n\x11RunInitiateResult\"\x12\n\x10RunCancelRequest\"\x13\n\x11RunCancelResponse\"=\n\x0fRunWatchRequest\x12*\n\x03run\x18\x01 \x01(\x0b\x32\x1d.eg.interp.events.RunMetadata\">\n\x0f\x44ispatchRequest\x12+\n\x08messages\x18\x01 \x03(\x0b\x32\x19.eg.interp.events.Message\"\x12\n\x10\x44ispatchResponse2\xcb\x02\n\x05\x41gent\x12S\n\x06Upload\x12 .eg.interp.events.RunUploadChunk\x1a#.eg.interp.events.RunUploadResponse\"\x00(\x01\x12S\n\x06\x43\x61ncel\x12\".eg.interp.events.RunCancelRequest\x1a#.eg.interp.events.RunCancelResponse\"\x00\x12M\n\x04Logs\x12\x1f.eg.interp.events.RunLogRequest\x1a .eg.interp.events.RunLogResponse\"\x00\x30\x01\x12I\n\x05Watch\x12!.eg.interp.events.RunWatchRequest\x1a\x19.eg.interp.events.Message\"\x00\x30\x01\x32]\n\x06\x45vents\x12S\n\x08\x44ispatch\x12!.eg.interp.events.DispatchRequest\x1a\".eg.interp.events.DispatchResponse\"\x00\x32]\n\x06Runner\x12S\n\x08\x44ispatch\x12!.eg.interp.events.DispatchRequest\x1a\".eg.interp.events.DispatchResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eg.interp.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RUNMETADATA']._serialized_start=44
  _globals['_RUNMETADATA']._serialized_end=69
  _globals['_LOGHEADER']._serialized_start=71
  _globals['_LOGHEADER']._serialized_end=153
  _globals['_HEARTBEAT']._serialized_start=155
  _globals['_HEARTBEAT']._serialized_end=166
  _globals['_TASK']._serialized_start=169
  _globals['_TASK']._serialized_end=348
  _globals['_TASK_STATE']._serialized_start=286
  _globals['_TASK_STATE']._serialized_end=348
  _globals['_METRIC']._serialized_start=350
  _globals['_METRIC']._serialized_end=400
  _globals['_MESSAGE']._serialized_start=403
  _globals['_MESSAGE']._serialized_end=628
  _globals['_RUNUPLOADCHUNK']._serialized_start=631
  _globals['_RUNUPLOADCHUNK']._serialized_end=827
  _globals['_RUNUPLOADCHUNK_METADATA']._serialized_start=760
  _globals['_RUNUPLOADCHUNK_METADATA']._serialized_end=803
  _globals['_RUNUPLOADRESPONSE']._serialized_start=829
  _globals['_RUNUPLOADRESPONSE']._serialized_end=892
  _globals['_RUNLOGREQUEST']._serialized_start=894
  _globals['_RUNLOGREQUEST']._serialized_end=953
  _globals['_RUNLOGRESPONSE']._serialized_start=955
  _globals['_RUNLOGRESPONSE']._serialized_end=988
  _globals['_RUNINITIATEREQUEST']._serialized_start=990
  _globals['_RUNINITIATEREQUEST']._serialized_end=1010
  _globals['_RUNINITIATERESULT']._serialized_start=1012
  _globals['_RUNINITIATERESULT']._serialized_end=1031
  _globals['_RUNCANCELREQUEST']._serialized_start=1033
  _globals['_RUNCANCELREQUEST']._serialized_end=1051
  _globals['_RUNCANCELRESPONSE']._serialized_start=1053
  _globals['_RUNCANCELRESPONSE']._serialized_end=1072
  _globals['_RUNWATCHREQUEST']._serialized_start=1074
  _globals['_RUNWATCHREQUEST']._serialized_end=1135
  _globals['_DISPATCHREQUEST']._serialized_start=1137
  _globals['_DISPATCHREQUEST']._serialized_end=1199
  _globals['_DISPATCHRESPONSE']._serialized_start=1201
  _globals['_DISPATCHRESPONSE']._serialized_end=1219
  _globals['_AGENT']._serialized_start=1222
  _globals['_AGENT']._serialized_end=1553
  _globals['_EVENTS']._serialized_start=1555
  _globals['_EVENTS']._serialized_end=1648
  _globals['_RUNNER']._serialized_start=1650
  _globals['_RUNNER']._serialized_end=1743
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from eg.interp import events_pb2 as eg_dot_interp_dot_events__pb2

GRPC_GENERATED_VERSION = '1.66.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in eg.interp.events_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AgentStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Upload = channel.stream_unary(
                '/eg.interp.events.Agent/Upload',
                request_serializer=eg_dot_interp_dot_events__pb2.RunUploadChunk.SerializeToString,
                response_deserializer=eg_dot_interp_dot_events__pb2.RunUploadResponse.FromString,
                _registered_method=True)
        self.Cancel = channel.unary_unary(
                '/eg.interp.events.Agent/Cancel',
                request_serializer=eg_dot_interp_dot_events__pb2.RunCancelRequest.SerializeToString,
                response_deserializer=eg_dot_interp_dot_events__pb2.RunCancelResponse.FromString,
                _registered_method=True)
        self.Logs = channel.unary_stream(
                '/eg.interp.events.Agent/Logs',
                request_serializer=eg_dot_interp_dot_events__pb2.RunLogRequest.SerializeToString,
                response_deserializer=eg_dot_interp_dot_events__pb2.RunLogResponse.FromString,
                _registered_method=True)
        self.Watch = channel.unary_stream(
                '/eg.interp.events.Agent/Watch',
                request_serializer=eg_dot_interp_dot_events__pb2.RunWatchRequest.SerializeToString,
                response_deserializer=eg_dot_interp_dot_events__pb2.Message.FromString,
                _registered_method=True)


class AgentServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Upload(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Cancel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Logs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Watch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AgentServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Upload': grpc.stream_unary_rpc_method_handler(
                    servicer.Upload,
                    request_deserializer=eg_dot_interp_dot_events__pb2.RunUploadChunk.FromString,
                    response_serializer=eg_dot_interp_dot_events__pb2.RunUploadResponse.SerializeToString,
            ),
            'Cancel': grpc.unary_unary_rpc_method_handler(
                    servicer.Cancel,
                    request_deserializer=eg_dot_interp_dot_events__pb2.RunCancelRequest.FromString,
                    response_serializer=eg_dot_interp_dot_events__pb2.RunCancelResponse.SerializeToString,
            ),
            'Logs': grpc.unary_stream_rpc_method_handler(
                    servicer.Logs,
                    request_deserializer=eg_dot_interp_dot_events__pb2.RunLogRequest.FromString,
                    response_serializer=eg_dot_interp_dot_events__pb2.RunLogResponse.SerializeToString,
            ),
            'Watch': grpc.unary_stream_rpc_method_handler(
                    servicer.Watch,
                    request_deserializer=eg_dot_interp_dot_events__pb2.RunWatchRequest.FromString,
                    response_serializer=eg_dot_interp_dot_events__pb2.Message.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'eg.interp.events.Agent', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('eg.interp.events.Agent', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Agent(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Upload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/eg.interp.events.Agent/Upload',
            eg_dot_interp_dot_events__pb2.RunUploadChunk.SerializeToString,
            eg_dot_interp_dot_events__pb2.RunUploadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Cancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/eg.interp.events.Agent/Cancel',
            eg_dot_interp_dot_events__pb2.RunCancelRequest.SerializeToString,
            eg_dot_interp_dot_events__pb2.RunCancelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Logs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/eg.interp.events.Agent/Logs',
            eg_dot_interp_dot_events__pb2.RunLogRequest.SerializeToString,
            eg_dot_interp_dot_events__pb2.RunLogResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Watch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/eg.interp.events.Agent/Watch',
            eg_dot_interp_dot_events__pb2.RunWatchRequest.SerializeToString,
            eg_dot_interp_dot_events__pb2.Message.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class EventsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Dispatch = channel.unary_unary(
                '/eg.interp.events.Events/Dispatch',
                request_serializer=eg_dot_interp_dot_events__pb2.DispatchRequest.SerializeToString,
                response_deserializer=eg_dot_interp_dot_events__pb2.DispatchResponse.FromString,
                _registered_method=True)


class EventsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Dispatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Dispatch': grpc.unary_unary_rpc_method_handler(
                    servicer.Dispatch,
                    request_deserializer=eg_dot_interp_dot_events__pb2.DispatchRequest.FromString,
                    response_serializer=eg_dot_interp_dot_events__pb2.DispatchResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'eg.interp.events.Events', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('eg.interp.events.Events', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Events(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Dispatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/eg.interp.events.Events/Dispatch',
            eg_dot_interp_dot_events__pb2.DispatchRequest.SerializeToString,
            eg_dot_interp_dot_events__pb2.DispatchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class RunnerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Dispatch = channel.unary_unary(
                '/eg.interp.events.Runner/Dispatch',
                request_serializer=eg_dot_interp_dot_events__pb2.DispatchRequest.SerializeToString,
                response_deserializer=eg_dot_interp_dot_events__pb2.DispatchResponse.FromString,
                _registered_method=True)


class RunnerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Dispatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RunnerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Dispatch': grpc.unary_unary_rpc_method_handler(
                    servicer.Dispatch,
                    request_deserializer=eg_dot_interp_dot_events__pb2.DispatchRequest.FromString,
                    response_serializer=eg_dot_interp_dot_events__pb2.DispatchResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'eg.interp.events.Runner', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('eg.interp.events.Runner', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Runner(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Dispatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/eg.interp.events.Runner/Dispatch',
            eg_dot_interp_dot_events__pb2.DispatchRequest.SerializeToString,
            eg_dot_interp_dot_events__pb2.DispatchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



import os
import time
import grpc
from . import interp
from uuid_extensions import uuid7str

def defaultRunnerRuntimeDir() -> str:
	return os.path.join("/", "opt", "egruntime")

def defaultRunnerSocketPath() -> str:
	return os.path.join(defaultRunnerRuntimeDir(), "control.socket")

def autoclient():
	return grpc.insecure_channel(defaultRunnerSocketPath())

def metric(name: str, fields: bytes):
		return interp.events_pb2.Message(
			id=uuid7str(),
			ts=time.time_ns() // 1000000,
			metric=interp.events_pb2.Metric(name=name, fieldsJSON=fields)
		)

def dispatch(*arg: interp.events_pb2.Message) -> interp.events_pb2.DispatchRequest:
	return interp.events_pb2.DispatchRequest(messages=arg)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RunMetadata(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: bytes
    def __init__(self, id: _Optional[bytes] = ...) -> None: ...

class LogHeader(_message.Message):
    __slots__ = ("Major", "Minor", "Patch", "sts", "ets")
    MAJOR_FIELD_NUMBER: _ClassVar[int]
    MINOR_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    STS_FIELD_NUMBER: _ClassVar[int]
    ETS_FIELD_NUMBER: _ClassVar[int]
    Major: int
    Minor: int
    Patch: int
    sts: int
    ets: int
    def __init__(self, Major: _Optional[int] = ..., Minor: _Optional[int] = ..., Patch: _Optional[int] = ..., sts: _Optional[int] = ..., ets: _Optional[int] = ...) -> None: ...

class Heartbeat(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class Task(_message.Message):
    __slots__ = ("id", "pid", "description", "state", "deadline")
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        Pending: _ClassVar[Task.State]
        Initiated: _ClassVar[Task.State]
        Completed: _ClassVar[Task.State]
        Error: _ClassVar[Task.State]
    Pending: Task.State
    Initiated: Task.State
    Completed: Task.State
    Error: Task.State
    ID_FIELD_NUMBER: _ClassVar[int]
    PID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    DEADLINE_FIELD_NUMBER: _ClassVar[int]
    id: str
    pid: str
    description: str
    state: Task.State
    deadline: int
    def __init__(self, id: _Optional[str] = ..., pid: _Optional[str] = ..., description: _Optional[str] = ..., state: _Optional[_Union[Task.State, str]] = ..., deadline: _Optional[int] = ...) -> None: ...

class Metric(_message.Message):
    __slots__ = ("name", "fieldsJSON")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FIELDSJSON_FIELD_NUMBER: _ClassVar[int]
    name: str
    fieldsJSON: bytes
    def __init__(self, name: _Optional[str] = ..., fieldsJSON: _Optional[bytes] = ...) -> None: ...

class Message(_message.Message):
    __slots__ = ("id", "ts", "preamble", "heartbeat", "task", "metric")
    ID_FIELD_NUMBER: _ClassVar[int]
    TS_FIELD_NUMBER: _ClassVar[int]
    PREAMBLE_FIELD_NUMBER: _ClassVar[int]
    HEARTBEAT_FIELD_NUMBER: _ClassVar[int]
    TASK_FIELD_NUMBER: _ClassVar[int]
    METRIC_FIELD_NUMBER: _ClassVar[int]
    id: str
    ts: int
    preamble: LogHeader
    heartbeat: Heartbeat
    task: Task
    metric: Metric
    def __init__(self, id: _Optional[str] = ..., ts: _Optional[int] = ..., preamble: _Optional[_Union[LogHeader, _Mapping]] = ..., heartbeat: _Optional[_Union[Heartbeat, _Mapping]] = ..., task: _Optional[_Union[Task, _Mapping]] = ..., metric: _Optional[_Union[Metric, _Mapping]] = ...) -> None: ...

class RunUploadChunk(_message.Message):
    __slots__ = ("data", "checksum", "none", "metadata")
    class Metadata(_message.Message):
        __slots__ = ("bytes", "checksum")
        BYTES_FIELD_NUMBER: _ClassVar[int]
        CHECKSUM_FIELD_NUMBER: _ClassVar[int]
        bytes: int
        checksum: bytes
        def __init__(self, bytes: _Optional[int] = ..., checksum: _Optional[bytes] = ...) -> None: ...
    DATA_FIELD_NUMBER: _ClassVar[int]
    CHECKSUM_FIELD_NUMBER: _ClassVar[int]
    NONE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    checksum: bytes
    none: bool
    metadata: RunUploadChunk.Metadata
    def __init__(self, data: _Optional[bytes] = ..., checksum: _Optional[bytes] = ..., none: bool = ..., metadata: _Optional[_Union[RunUploadChunk.Metadata, _Mapping]] = ...) -> None: ...

class RunUploadResponse(_message.Message):
    __slots__ = ("run",)
    RUN_FIELD_NUMBER: _ClassVar[int]
    run: RunMetadata
    def __init__(self, run: _Optional[_Union[RunMetadata, _Mapping]] = ...) -> None: ...

class RunLogRequest(_message.Message):
    __slots__ = ("run",)
    RUN_FIELD_NUMBER: _ClassVar[int]
    run: RunMetadata
    def __init__(self, run: _Optional[_Union[RunMetadata, _Mapping]] = ...) -> None: ...

class RunLogResponse(_message.Message):
    __slots__ = ("content",)
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    content: bytes
    def __init__(self, content: _Optional[bytes] = ...) -> None: ...

class RunInitiateRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RunInitiateResult(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RunCancelRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RunCancelResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RunWatchRequest(_message.Message):
    __slots__ = ("run",)
    RUN_FIELD_NUMBER: _ClassVar[int]
    run: RunMetadata
    def __init__(self, run: _Optional[_Union[RunMetadata, _Mapping]] = ...) -> None: ...

class DispatchRequest(_message.Message):
    __slots__ = ("messages",)
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    messages: _containers.RepeatedCompositeFieldContainer[Message]
    def __init__(self, messages: _Optional[_Iterable[_Union[Message, _Mapping]]] = ...) -> None: ...

class DispatchResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...
